#
# spec file for package harec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           harec
Release:        1.1
Version:        1702179030.9d51b36
Summary:        Bootstrap compiler for hare
Group:          Development/Tools/Building
URL:            https://git.sr.ht/~sircmpwn/harec
Source0:        %{name}-%{version}.tar.zst
Source1:        README-suse-maint.md
BuildRequires:  make
BuildRequires:  qbe
BuildRequires:  zstd
License:        GPL-3.0-only

%description

HareC is a bootstrap compiler for the Hare programming language. Written in C11 for
POSIX-compatible systems.

%prep
%setup -q
mkdir -p build/

%build

export CFLAGS="%optflags"

# Harec does not use autoconf
pushd build/
../configure
make %{?_smp_mflags}
popd

%install
export CFLAGS="%optflags"
pushd build/
make %{?_smp_mflags} DESTDIR="%{buildroot}" BINDIR="%{_bindir}" install
popd

%check
export CFLAGS="%optflags"
cd build
../configure
make %{?_smp_mflags} check

%files
%{_bindir}/%{name}
%license COPYING
%doc     README.md

%changelog
* Sat Dec 16 2023 socvirnyl.estela@gmail.com
- Update to version 1702179030.9d51b36:
  * scope: split up scope_lookup_ancestor
  * Implement for labels
  * Implement switch/match labels
  * check: fix enum alias importing
  * tests/34-declarations: add invalid symbol tests
  * parse: disallow empty symbol
  * type_store: fix tagged union segfault
  * all: use literal/flexible in place of constant
  * main: check for fmemopen error
  * mod: remove unnecessary allocation
  * tests: fix broken rejection tests
  * type_store: make builtin_type_error have zero size/alignment
* Fri Dec  8 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add README-suse-maint.md
* Fri Dec  8 2023 socvirnyl.estela@gmail.com
- Update to version 1701558776.08af325:
  * OpenBSD: Fix _start for arm64.
* Sat Dec  2 2023 socvirnyl.estela@gmail.com
- Update to version 1701262234.ec3193e:
  * types: recover from circular dependency error
  * check,gen: use name instead of ident to create global_decl declarations
  * Revert "types: recover from circular dependency error"
  * types: recover from circular dependency error
  * type_store: pass around check context
  * type_store: detect duplicate fields in embedded structs/unions
  * check: improve error message
  * ast: make ast_enum_field name non-const
  * all: use const for more function params
  * scope: put type and value in a union
  * rt, tests: drop EXIT_FAILURE
  * check: resolve type when taking size/alignment
  * check: replace expression_measure with expression_len
  * check: allow taking alignment of zero-size type
  * parse: add error function
  * lex: use error func for unexpected codepoint error
  * check: remove unnecessary memset
  * parse: disallow casting to null
  * Move func_decl_flags from check.h to ast.h
  * parse: add missing va_ends
  * main: use xfprintf with harec -v
  * gen: use u32 instead of uint for tag
  * check: allow freeing null
  * qtype: fix memory leak
  * check: disallow append/inserting with undefined-size member
  * check: disallow unbounded array value in append/insert
  * parse: disallow ellipsis in append/insert length form
  * tests: make insert rejection tests consistent with append
  * tests: fix append/insert rejection tests
  * check: fix append/insert value dereferencing
  * parse, check: update imports
  * all: fix format specifiers
  * check: be more picky about default values of arrays
  * implement checkless for loops
* Sat Nov 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Improve specfile. Add some comments
* Fri Nov 10 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update groups section in specfile
* Fri Nov 10 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add install command.
* Fri Nov 10 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Dont pin version requirment on qbe
* Fri Nov 10 2023 socvirnyl.estela@gmail.com
- Update to version 1699297758.b4dd427:
  * parse: improve error message
  * all: remove another spurious error
  * check: recover from errors in resolve_type
  * type_store: fix signed array length check
  * gen.c: Fix warning which lets build fail
  * Improve handling of invalid UTF-8 in rune/str literals
  * check: make error msg more accurate
  * Revert "convert redundant check to assert"
  * Add zero-size bindings
  * check: recover from errors in check_function
* Sun Aug 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove no-exec-stack.patch. Seems they use noexec stack already.
* Sun Aug 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add no-exec-stack.patch
* Sun Aug 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0+1630:
  * fix type promotion with STORAGE_ERROR on the right
  * link tests with -z noexecstack
  * emit line number info
  * identifier: use xrealloc instead of allocating new memory
  * lex: remove pointless _lex function
  * Return EXIT_SUCCESS when -h is used
  * types: make tagged unions castable to invalid
  * doc/runtime.txt: remove runtime behavior descriptions
  * check: disallow initializing object with undefined size
  * check: disallow assigning to object with undefined size
  * Revert nested defers
  * Remove cap built-in
  * Remove accidentally added test
  * check: handle errors without (ab)using type hints
  * Revert "Implement new hosted environment requirements"
  * Allow top-level static assertions
  * Remove unary +
  * check: disallow @symbol alongside other attributes
  * check: disallow @init, @fini, and @test on prototypes
  * Implement new hosted environment requirements
  * docs: document NO_COLOR and HAREC_COLOR
  * rt: pass raw compile flags to harec
  * Make pointer/slice assignability rules more strict
  * check: add implicit yield at end of compound expr
  * Remove implicit const flag from function decls
  * Remove cursed bool test
  * check: show visual marker for all errors
  * lex: add static assertion for tokens array length
  * eval: fix abort when evaluating measure expr on ERROR
  * Add cap builtin
  * check: always perform result reduction on if expr
  * parse: allow return and yield in more places
  * tests: remove magic exit status from 09-funcs
  * check: remove ctx->deferring
  * check, gen: allow nested defers
  * check: remove unnecessary defer check
  * check: disallow jumping out of defer
  * parse: fix import name list parsing
  * Link with libm
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat Jul 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to 0+1591:
  * qbe: make offset field int64_t instead of long [f16e979] - Sebastian <sebastian@sebsite.pw>
  * all: replace intmax_t with int64_t [18a73fb] - Sebastian <sebastian@sebsite.pw>
  * drop expression parameter from error_norec [c1259f6] - Ember Sawady <ecs@d2evs.net>
  * type_dealias: resolve incomplete aliases [506bd08] - Ember Sawady <ecs@d2evs.net>
  * thread check context into type_dealias [8b17997] - Ember Sawady <ecs@d2evs.net>
  * get rid of yet another spurious error [618f28b] - Ember Sawady <ecs@d2evs.net>
  * type store: s/uint/u32/ for tagged union tags [c2e1ec3] - Ember Sawady <ecs@d2evs.net>
  * avoid segfault on return with invalid parameters [0424adb] - Ember Sawady <ecs@d2evs.net>
  * extend sub-word types before relevant bin/unarithms [f5da14c] - Ember Sawady <ecs@d2evs.net>
  * Get rid of more spurious errors [89133d4] - Ember Sawady <ecs@d2evs.net>
  * Rewrite malloc [7a27d96] - Ember Sawady <ecs@d2evs.net>
  * rt: fix typo [174aef4] - Sebastian <sebastian@sebsite.pw>
  * Add harec -v [a66a324] - Ember Sawady <ecs@d2evs.net>
  * lex: make E and P in literals case-insensitive [efc9cc3] - Ember Sawady <ecs@d2evs.net>
  * rt+freebsd: _start: don't touch first arg [d8db334] - Ember Sawady <ecs@d2evs.net>
  * Emit an abort at the end of @noreturn functions [22e4ade] - Ember Sawady <ecs@d2evs.net>
  * emit precise hexadecimal floats in typedef.c [8ea475e] - Bor Grošelj Simić <bgs@turminal.net>
  * implement hex float literals [0c77e6a] - Bor Grošelj Simić <bgs@turminal.net>
  * check: lower the failing case of ! to default match case [2ac0c5f] - Bor Grošelj Simić <bgs@turminal.net>
  * gen: utilize qbe's new hlt instruction [209ca85] - Bor Grošelj Simić <bgs@turminal.net>
  * Add missing comma in abort reasons [4718e74] - Ember Sawady <ecs@d2evs.net>
  * gen: put all rt functions into a struct [609c0ca] - Bor Grošelj Simić <bgs@turminal.net>
  * check: no default value for enums without zero value [9b4c417] - Sebastian <sebastian@sebsite.pw>
  * check: disallow autofilling fields without default values [189dfc9] - Sebastian <sebastian@sebsite.pw>
  * gen: remove some obsolete utility functions [8917e4a] - Bor Grošelj Simić <bgs@turminal.net>
  * expr_propagate: make "error occured" a fixed abort [9632c11] - Bor Grošelj Simić <bgs@turminal.net>
  * allow assert/abort with non-constant message [f4ab18a] - Bor Grošelj Simić <bgs@turminal.net>
  * check: handle static assertions without passing them on [186f301] - Bor Grošelj Simić <bgs@turminal.net>
  * add a utility function for constant string exprs [d7231f6] - Bor Grošelj Simić <bgs@turminal.net>
  * all: add xfprintf function which exits for I/O errors [db642ac] - Sebastian <sebastian@sebsite.pw>
  * Permit C-style variadism with no named params [cbe828e] - Sebastian <sebastian@sebsite.pw>
  * docs/runtime.txt: document recently added fixed abort reason [16aa2bb] - Bor Grošelj Simić <bgs@turminal.net>
  * expr.h: remove unused struct expression_propagate [6afa5af] - Bor Grošelj Simić <bgs@turminal.net>
  * all: correct xcalloc argument order [b092fc5] - Sebastian <sebastian@sebsite.pw>
  * Refactor typedef environment variables [dfc1dd1] - Ember Sawady <ecs@d2evs.net>
  * eval_measurement: implement len for arrays [f12153b] - Umar Getagazov <umar@handlerug.me>
  * Allow empty -N option arg [9c4c5c7] - Autumn! <autumnull@posteo.net>
  * error: Align located messages with other toolchains [7f5eb3f] - Dridi Boukelmoune <dridi.boukelmoune@gmail.com>
  * Remove _ from function parameters. [01cb763] - Joe Finney <me@spxtr.net>
  * Loosen uintptr promotion rules [9bf57f6] - Ember Sawady <ecs@d2evs.net>
  * Drop HA_STAGE [72c917b] - Ember Sawady <ecs@d2evs.net>
  * Remove char [3dfde59] - Sebastian <sebastian@sebsite.pw>
  * Abort instead of SEGFAULT when slice alloc cap < length [a3b22ca] - Autumn! <autumnull@posteo.net>
  * ensure operands and operators match in special assignment expressions [151a0a2] - Bor Grošelj Simić <bgs@turminal.net>
  * check: extract binop validity checking into a separate function [36868d0] - Bor Grošelj Simić <bgs@turminal.net>
  * Add more binarithms tests [aaf2c2f] - Sebastian <sebastian@sebsite.pw>
  * eval: fix signed binarithm operations [76bf2d6] - Sebastian <sebastian@sebsite.pw>
  * gen: correctly copy first member in expandable arrays [d436570] - Bor Grošelj Simić <bgs@turminal.net>
* Sat May 27 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to 0+1562:
  * all: add xfprintf function which exits for I/O errors
  * permit C-style variadism with no named params
  * docs/runtime.txt: document recently added fixed abort reason
  * expr.h: remove unused struct expression_propagate
  * all: correct xcalloc argument order
  * Refactor typedef environment variables
  * eval_measurement: implement len for arrays
  * allow empty -N option arg
  * error: align located messages with other toolchains
  * Remove _ from function parameters.
* Sat Mar 11 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Enable test suite
* Tue Feb 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for harec 0+git1514
